Auxiliary modules
=================

Timer module
------------

.. automodule:: tamkin.timer
   :members:

Standard representation of QM or MM data
----------------------------------------

**Inheritance diagram**

.. inheritance-diagram:: tamkin.data

.. automodule:: tamkin.data
   :members:
   :show-inheritance:

Analysis of molecular geometries
--------------------------------

.. automodule:: tamkin.geom
   :members:
